@@ -12,13 +12,13 @@ package org.gnu.gnome;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DruidPageChangeEvent;
 import org.gnu.gnome.event.DruidPageChangeListener;
 import org.gnu.gnome.event.DruidPageSetupEvent;
 import org.gnu.gnome.event.DruidPageSetupListener;
 import org.gnu.gtk.Bin;
-import org.gnu.gtk.event.GtkEventType;
 /**
  * This widget is a virtual widget to define the interface to a druid
  * page.
@@ -175,8 +175,8 @@ public class DruidPage extends Bin {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
