@@ -12,13 +12,13 @@ package org.gnu.gnome;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.FontPickerEvent;
 import org.gnu.gnome.event.FontPickerListener;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Widget;
-import org.gnu.gtk.event.GtkEventType;
 /**
  * The FontPicker widget is a button that, when selected, presents
  * a window that enables the user to select from among the many
@@ -37,7 +37,6 @@ public class FontPicker extends Button {
 	 */
 	public FontPicker() {
 		super(gnome_font_picker_new());
-		initializeEventHandlers();
 	}
 
 	/**
@@ -45,7 +44,6 @@ public class FontPicker extends Button {
 	 */
 	public FontPicker(int handle) {
 		super(handle);
-		initializeEventHandlers();
 	}
 
 	/**
@@ -178,6 +176,7 @@ public class FontPicker extends Button {
 		int i = findListener(fontPickerListeners, listener);
 		if (i == -1) {
 			if (null == fontPickerListeners) {
+				evtMap.initialize(this, FontPickerEvent.Type.FONT_SET);
 				fontPickerListeners = new Vector();
 			}
 			fontPickerListeners.addElement(listener);
@@ -193,6 +192,7 @@ public class FontPicker extends Button {
 			fontPickerListeners.remove(i);
 		}
 		if (0 == fontPickerListeners.size()) {
+			evtMap.uninitialize(this, FontPickerEvent.Type.FONT_SET);
 			fontPickerListeners = null;
 		}
 	}
@@ -214,22 +214,14 @@ public class FontPicker extends Button {
 		fireFontPickerEvent(new FontPickerEvent(this));
 	}
 
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			super.initializeEventHandlers();
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
