@@ -12,11 +12,11 @@ package org.gnu.gnome;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.IconEntryEvent;
 import org.gnu.gnome.event.IconEntryListener;
 import org.gnu.gtk.VBox;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * A GnomeIconEntry is a button that pops up a window displaying a
@@ -34,7 +34,6 @@ public class IconEntry extends VBox {
 	 */
 	public IconEntry(String historyId, String dialogTitle) {
 		super(gnome_icon_entry_new(historyId, dialogTitle));
-		initializeEventHandlers();
 	}
 	
 	/**
@@ -42,7 +41,6 @@ public class IconEntry extends VBox {
 	 */
 	public IconEntry(int handle) {
 	    super(handle);
-	    initializeEventHandlers();
 	}
 	
 	/**
@@ -108,6 +106,8 @@ public class IconEntry extends VBox {
 		int i = findListener(listeners, listener);
 		if (i == -1) {
 			if (null == listeners) {
+				evtMap.initialize(this, IconEntryEvent.Type.BROWSE);
+				evtMap.initialize(this, IconEntryEvent.Type.CHANGED);
 				listeners = new Vector();
 			}
 			listeners.addElement(listener);
@@ -123,6 +123,8 @@ public class IconEntry extends VBox {
 			listeners.remove(i);
 		}
 		if (0 == listeners.size()) {
+			evtMap.uninitialize(this, IconEntryEvent.Type.BROWSE);
+			evtMap.uninitialize(this, IconEntryEvent.Type.CHANGED);
 			listeners = null;
 		}
 	}
@@ -148,22 +150,14 @@ public class IconEntry extends VBox {
 		fireIconEntryEvent(new IconEntryEvent(this, IconEntryEvent.Type.BROWSE));
 	}
 	
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			super.initializeEventHandlers();
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
