@@ -14,8 +14,8 @@
 
 package org.gnu.gnome.event;
 
+import org.gnu.glib.EventType;
 import org.gnu.gtk.event.GtkEvent;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * An event represeting action by a {@link org.gnu.gnome.ColorPicker} widget.
@@ -24,7 +24,7 @@ import org.gnu.gtk.event.GtkEventType;
  */
 public class ColorPickerEvent extends GtkEvent {
 
-    public static class Type extends GtkEventType{
+    public static class Type extends EventType{
 	private Type(int id, String name){
 	    super(id, name);
 	}
